Visualizing data
----------------
.. index::
    single: Visualizing data

So far we have been learning the Python language and then learning how
to use Python, the network, and databases to manipulate data.

In this chapter, we take a look at three complete applications that
bring all of these things together to manage and visualize data. You
might use these applications as sample code to help get you started in
solving a real-world problem.

Each of the applications is a ZIP file that you can download and extract
onto your computer and execute.

.. fillintheblank:: viz-fitb-apps

    How many complete applications are used in this chapter to visualize data?

    - :3|([Tt]hree): In this chapter, we look at three complete applicatins to visualize data.
      :.*: Try again!

.. fillintheblank:: viz-fitb-file

    What type of downloadable file are the applications?

    - :[Zz][Ii][Pp]: Each application is a ZIP file that can be downloaded and extracted.
      :.*: Try again!
